@@ -45,15 +45,19 @@
 { data: { id: "matrix", name: "matrix", parent: "cluster_algebra", released: "no" } },
 { data: { id: "zmodp", name: "zmodp", parent: "cluster_algebra", released: "no" } },
 { data: { id: "fraction", name: "fraction", parent: "cluster_algebra", released: "no" } },
-{ data: { id: "polydiv", name: "polydiv", parent: "cluster_algebra", released: "no" } },
 { data: { id: "mxalgebra", name: "mxalgebra", parent: "cluster_algebra", released: "no" } },
+{ data: { id: "polydiv", name: "polydiv", parent: "cluster_algebra", released: "no" } },
+{ data: { id: "mxpoly", name: "mxpoly", parent: "cluster_algebra", released: "no" } },
 { data: { id: "poly", name: "poly", parent: "cluster_algebra", released: "no" } },
 { data: { id: "ssrint", name: "ssrint", parent: "cluster_algebra", released: "no" } },
 { data: { id: "rat", name: "rat", parent: "cluster_algebra", released: "no" } },
 { data: { id: "ssrnum", name: "ssrnum", parent: "cluster_algebra", released: "no" } },
-{ data: { id: "mxpoly", name: "mxpoly", parent: "cluster_algebra", released: "no" } },
 { data: { id: "ssralg", name: "ssralg", parent: "cluster_algebra", released: "no" } },
+{ data: { id: "countalg", name: "countalg", parent: "cluster_algebra", released: "no" } },
 { data: { id: "intdiv", name: "intdiv", parent: "cluster_algebra", released: "no" } },
+{ data: { id: "cluster_test_suite", name: "test_suite" } },
+{ data: { id: "cluster_test_suite_plus", name: "+", parent: "cluster_test_suite" } },
+{ data: { id: "hierarchy_test", name: "hierarchy_test", parent: "cluster_test_suite", released: "no" } },
 { data: { id: "cluster_character", name: "character" } },
 { data: { id: "cluster_character_plus", name: "+", parent: "cluster_character" } },
 { data: { id: "inertia", name: "inertia", parent: "cluster_character", released: "no" } },
@@ -94,12 +98,11 @@
 { data: { id: "galois", name: "galois", parent: "cluster_field", released: "no" } },
 { data: { id: "separable", name: "separable", parent: "cluster_field", released: "no" } },
 { data: { id: "all_field", name: "all_field", parent: "cluster_field", released: "no" } },
-{ data: { id: "algC", name: "algC", parent: "cluster_field", released: "no" } },
 { data: { id: "cyclotomic", name: "cyclotomic", parent: "cluster_field", released: "no" } },
 { data: { id: "fieldext", name: "fieldext", parent: "cluster_field", released: "no" } },
-{ data: { id: "closed_field", name: "closed_field", parent: "cluster_field", released: "no" } },
-{ data: { id: "countalg", name: "countalg", parent: "cluster_field", released: "no" } },
+{ data: { id: "algC", name: "algC", parent: "cluster_field", released: "no" } },
 { data: { id: "algebraics_fundamentals", name: "algebraics_fundamentals", parent: "cluster_field", released: "no" } },
+{ data: { id: "closed_field", name: "closed_field", parent: "cluster_field", released: "no" } },
 { data: { id: "finfield", name: "finfield", parent: "cluster_field", released: "no" } },
 { data: { id: "algnum", name: "algnum", parent: "cluster_field", released: "no" } },
 { data: { id: "falgebra", name: "falgebra", parent: "cluster_field", released: "no" } },
@@ -112,152 +115,147 @@
 { data: { id: "edge6", source: "tuple", target: "fintype" } },
 { data: { id: "edge7", source: "all_algebra", target: "interval" } },
 { data: { id: "edge8", source: "all_ssreflect", target: "fingraph" } },
-{ data: { id: "edge9", source: "fieldext", target: "generic_quotient" } },
-{ data: { id: "edge10", source: "all_ssreflect", target: "generic_quotient" } },
-{ data: { id: "edge11", source: "fraction", target: "generic_quotient" } },
-{ data: { id: "edge12", source: "ring_quotient", target: "generic_quotient" } },
-{ data: { id: "edge13", source: "all", target: "all_ssreflect" } },
-{ data: { id: "edge14", source: "maximal", target: "finmodule" } },
-{ data: { id: "edge15", source: "vcharacter", target: "integral_char" } },
+{ data: { id: "edge9", source: "all_ssreflect", target: "generic_quotient" } },
+{ data: { id: "edge10", source: "ring_quotient", target: "generic_quotient" } },
+{ data: { id: "edge11", source: "all", target: "all_ssreflect" } },
+{ data: { id: "edge12", source: "maximal", target: "finmodule" } },
+{ data: { id: "edge13", source: "mxpoly", target: "polydiv" } },
+{ data: { id: "edge14", source: "fraction", target: "polydiv" } },
+{ data: { id: "edge15", source: "intdiv", target: "polydiv" } },
 { data: { id: "edge16", source: "all", target: "all_character" } },
 { data: { id: "edge17", source: "vector", target: "mxalgebra" } },
 { data: { id: "edge18", source: "mxpoly", target: "mxalgebra" } },
-{ data: { id: "edge19", source: "poly", target: "ssralg" } },
-{ data: { id: "edge20", source: "ring_quotient", target: "ssralg" } },
-{ data: { id: "edge21", source: "finalg", target: "ssralg" } },
-{ data: { id: "edge22", source: "classfun", target: "algnum" } },
-{ data: { id: "edge23", source: "all_field", target: "algnum" } },
-{ data: { id: "edge24", source: "all_character", target: "inertia" } },
-{ data: { id: "edge25", source: "burnside_app", target: "primitive_action" } },
-{ data: { id: "edge26", source: "alt", target: "primitive_action" } },
-{ data: { id: "edge27", source: "all_solvable", target: "burnside_app" } },
-{ data: { id: "edge28", source: "all", target: "all_solvable" } },
-{ data: { id: "edge29", source: "automorphism", target: "perm" } },
-{ data: { id: "edge30", source: "eqtype", target: "ssreflect" } },
-{ data: { id: "edge31", source: "falgebra", target: "vector" } },
-{ data: { id: "edge32", source: "intdiv", target: "vector" } },
-{ data: { id: "edge33", source: "all_fingroup", target: "gproduct" } },
-{ data: { id: "edge34", source: "gfunctor", target: "gproduct" } },
-{ data: { id: "edge35", source: "cyclic", target: "gproduct" } },
-{ data: { id: "edge36", source: "fingroup", target: "prime" } },
-{ data: { id: "edge37", source: "binomial", target: "prime" } },
-{ data: { id: "edge38", source: "fintype", target: "choice" } },
-{ data: { id: "edge39", source: "commutator", target: "gfunctor" } },
-{ data: { id: "edge40", source: "center", target: "gfunctor" } },
-{ data: { id: "edge41", source: "pgroup", target: "gfunctor" } },
-{ data: { id: "edge42", source: "character", target: "abelian" } },
-{ data: { id: "edge43", source: "maximal", target: "abelian" } },
-{ data: { id: "edge44", source: "finfield", target: "abelian" } },
-{ data: { id: "edge45", source: "all_character", target: "mxabelem" } },
-{ data: { id: "edge46", source: "bigop", target: "finfun" } },
-{ data: { id: "edge47", source: "fieldext", target: "mxpoly" } },
-{ data: { id: "edge48", source: "polyXY", target: "mxpoly" } },
-{ data: { id: "edge49", source: "mxrepresentation", target: "mxpoly" } },
-{ data: { id: "edge50", source: "ssrint", target: "ssrnum" } },
-{ data: { id: "edge51", source: "prime", target: "bigop" } },
-{ data: { id: "edge52", source: "finset", target: "bigop" } },
-{ data: { id: "edge53", source: "seq", target: "ssrnat" } },
-{ data: { id: "edge54", source: "algebraics_fundamentals", target: "galois" } },
-{ data: { id: "edge55", source: "finmodule", target: "commutator" } },
-{ data: { id: "edge56", source: "gseries", target: "commutator" } },
-{ data: { id: "edge57", source: "mxrepresentation", target: "commutator" } },
-{ data: { id: "edge58", source: "integral_char", target: "character" } },
-{ data: { id: "edge59", source: "inertia", target: "character" } },
-{ data: { id: "edge60", source: "gseries", target: "center" } },
-{ data: { id: "edge61", source: "mxrepresentation", target: "center" } },
-{ data: { id: "edge62", source: "primitive_action", target: "gseries" } },
-{ data: { id: "edge63", source: "jordanholder", target: "gseries" } },
-{ data: { id: "edge64", source: "nilpotent", target: "gseries" } },
-{ data: { id: "edge65", source: "inertia", target: "frobenius" } },
-{ data: { id: "edge66", source: "all_solvable", target: "frobenius" } },
-{ data: { id: "edge67", source: "vcharacter", target: "frobenius" } },
-{ data: { id: "edge68", source: "all_algebra", target: "fraction" } },
-{ data: { id: "edge69", source: "all_solvable", target: "jordanholder" } },
-{ data: { id: "edge70", source: "mxalgebra", target: "matrix" } },
-{ data: { id: "edge71", source: "extremal", target: "matrix" } },
-{ data: { id: "edge72", source: "extraspecial", target: "extremal" } },
-{ data: { id: "edge73", source: "frobenius", target: "hall" } },
-{ data: { id: "edge74", source: "all_solvable", target: "extraspecial" } },
-{ data: { id: "edge75", source: "bigop", target: "div" } },
-{ data: { id: "edge76", source: "all_solvable", target: "alt" } },
-{ data: { id: "edge77", source: "all_fingroup", target: "presentation" } },
-{ data: { id: "edge78", source: "extremal", target: "presentation" } },
-{ data: { id: "edge79", source: "cyclotomic", target: "algC" } },
-{ data: { id: "edge80", source: "ssrnum", target: "poly" } },
-{ data: { id: "edge81", source: "falgebra", target: "poly" } },
-{ data: { id: "edge82", source: "cyclic", target: "poly" } },
+{ data: { id: "edge19", source: "poly", target: "countalg" } },
+{ data: { id: "edge20", source: "finalg", target: "countalg" } },
+{ data: { id: "edge21", source: "classfun", target: "algnum" } },
+{ data: { id: "edge22", source: "all_field", target: "algnum" } },
+{ data: { id: "edge23", source: "perm", target: "fingroup" } },
+{ data: { id: "edge24", source: "ssrnum", target: "fingroup" } },
+{ data: { id: "edge25", source: "morphism", target: "fingroup" } },
+{ data: { id: "edge26", source: "burnside_app", target: "primitive_action" } },
+{ data: { id: "edge27", source: "alt", target: "primitive_action" } },
+{ data: { id: "edge28", source: "all_solvable", target: "burnside_app" } },
+{ data: { id: "edge29", source: "all", target: "all_solvable" } },
+{ data: { id: "edge30", source: "automorphism", target: "perm" } },
+{ data: { id: "edge31", source: "ssrfun", target: "ssreflect" } },
+{ data: { id: "edge32", source: "falgebra", target: "vector" } },
+{ data: { id: "edge33", source: "intdiv", target: "vector" } },
+{ data: { id: "edge34", source: "all_fingroup", target: "gproduct" } },
+{ data: { id: "edge35", source: "gfunctor", target: "gproduct" } },
+{ data: { id: "edge36", source: "cyclic", target: "gproduct" } },
+{ data: { id: "edge37", source: "fingroup", target: "prime" } },
+{ data: { id: "edge38", source: "binomial", target: "prime" } },
+{ data: { id: "edge39", source: "fintype", target: "choice" } },
+{ data: { id: "edge40", source: "commutator", target: "gfunctor" } },
+{ data: { id: "edge41", source: "center", target: "gfunctor" } },
+{ data: { id: "edge42", source: "pgroup", target: "gfunctor" } },
+{ data: { id: "edge43", source: "character", target: "abelian" } },
+{ data: { id: "edge44", source: "maximal", target: "abelian" } },
+{ data: { id: "edge45", source: "finfield", target: "abelian" } },
+{ data: { id: "edge46", source: "all_character", target: "mxabelem" } },
+{ data: { id: "edge47", source: "bigop", target: "finfun" } },
+{ data: { id: "edge48", source: "fieldext", target: "mxpoly" } },
+{ data: { id: "edge49", source: "closed_field", target: "mxpoly" } },
+{ data: { id: "edge50", source: "polyXY", target: "mxpoly" } },
+{ data: { id: "edge51", source: "mxrepresentation", target: "mxpoly" } },
+{ data: { id: "edge52", source: "interval", target: "ssrnum" } },
+{ data: { id: "edge53", source: "ssrint", target: "ssrnum" } },
+{ data: { id: "edge54", source: "prime", target: "bigop" } },
+{ data: { id: "edge55", source: "finset", target: "bigop" } },
+{ data: { id: "edge56", source: "seq", target: "ssrnat" } },
+{ data: { id: "edge57", source: "algebraics_fundamentals", target: "galois" } },
+{ data: { id: "edge58", source: "finmodule", target: "commutator" } },
+{ data: { id: "edge59", source: "gseries", target: "commutator" } },
+{ data: { id: "edge60", source: "mxrepresentation", target: "commutator" } },
+{ data: { id: "edge61", source: "inertia", target: "character" } },
+{ data: { id: "edge62", source: "integral_char", target: "character" } },
+{ data: { id: "edge63", source: "gseries", target: "center" } },
+{ data: { id: "edge64", source: "mxrepresentation", target: "center" } },
+{ data: { id: "edge65", source: "primitive_action", target: "gseries" } },
+{ data: { id: "edge66", source: "jordanholder", target: "gseries" } },
+{ data: { id: "edge67", source: "nilpotent", target: "gseries" } },
+{ data: { id: "edge68", source: "all_solvable", target: "frobenius" } },
+{ data: { id: "edge69", source: "inertia", target: "frobenius" } },
+{ data: { id: "edge70", source: "vcharacter", target: "frobenius" } },
+{ data: { id: "edge71", source: "hierarchy_test", target: "all" } },
+{ data: { id: "edge72", source: "all_solvable", target: "jordanholder" } },
+{ data: { id: "edge73", source: "mxalgebra", target: "matrix" } },
+{ data: { id: "edge74", source: "extremal", target: "matrix" } },
+{ data: { id: "edge75", source: "extraspecial", target: "extremal" } },
+{ data: { id: "edge76", source: "frobenius", target: "hall" } },
+{ data: { id: "edge77", source: "all_solvable", target: "extraspecial" } },
+{ data: { id: "edge78", source: "bigop", target: "div" } },
+{ data: { id: "edge79", source: "all_solvable", target: "alt" } },
+{ data: { id: "edge80", source: "all_fingroup", target: "presentation" } },
+{ data: { id: "edge81", source: "extremal", target: "presentation" } },
+{ data: { id: "edge82", source: "cyclotomic", target: "algC" } },
 { data: { id: "edge83", source: "polydiv", target: "poly" } },
-{ data: { id: "edge84", source: "ssrfun", target: "ssrnotations" } },
-{ data: { id: "edge85", source: "countalg", target: "rat" } },
-{ data: { id: "edge86", source: "intdiv", target: "rat" } },
-{ data: { id: "edge87", source: "sylow", target: "nilpotent" } },
-{ data: { id: "edge88", source: "countalg", target: "closed_field" } },
-{ data: { id: "edge89", source: "choice", target: "seq" } },
-{ data: { id: "edge90", source: "div", target: "seq" } },
-{ data: { id: "edge91", source: "path", target: "seq" } },
-{ data: { id: "edge92", source: "fingroup", target: "finset" } },
-{ data: { id: "edge93", source: "binomial", target: "finset" } },
-{ data: { id: "edge94", source: "countalg", target: "ring_quotient" } },
-{ data: { id: "edge95", source: "all_algebra", target: "ring_quotient" } },
-{ data: { id: "edge96", source: "fingraph", target: "path" } },
-{ data: { id: "edge97", source: "bigop", target: "path" } },
+{ data: { id: "edge84", source: "ssrnum", target: "poly" } },
+{ data: { id: "edge85", source: "falgebra", target: "poly" } },
+{ data: { id: "edge86", source: "cyclic", target: "poly" } },
+{ data: { id: "edge87", source: "ssrfun", target: "ssrnotations" } },
+{ data: { id: "edge88", source: "intdiv", target: "rat" } },
+{ data: { id: "edge89", source: "sylow", target: "nilpotent" } },
+{ data: { id: "edge90", source: "fieldext", target: "falgebra" } },
+{ data: { id: "edge91", source: "choice", target: "seq" } },
+{ data: { id: "edge92", source: "div", target: "seq" } },
+{ data: { id: "edge93", source: "path", target: "seq" } },
+{ data: { id: "edge94", source: "fingroup", target: "finset" } },
+{ data: { id: "edge95", source: "binomial", target: "finset" } },
+{ data: { id: "edge96", source: "countalg", target: "ring_quotient" } },
+{ data: { id: "edge97", source: "fintype", target: "path" } },
 { data: { id: "edge98", source: "gproduct", target: "action" } },
 { data: { id: "edge99", source: "finalg", target: "action" } },
-{ data: { id: "edge100", source: "perm", target: "fingroup" } },
-{ data: { id: "edge101", source: "morphism", target: "fingroup" } },
-{ data: { id: "edge102", source: "algebraics_fundamentals", target: "countalg" } },
+{ data: { id: "edge100", source: "algebraics_fundamentals", target: "closed_field" } },
+{ data: { id: "edge101", source: "algnum", target: "cyclotomic" } },
+{ data: { id: "edge102", source: "finfield", target: "cyclotomic" } },
 { data: { id: "edge103", source: "all", target: "all_algebra" } },
-{ data: { id: "edge104", source: "algnum", target: "cyclotomic" } },
-{ data: { id: "edge105", source: "finfield", target: "cyclotomic" } },
-{ data: { id: "edge106", source: "galois", target: "separable" } },
-{ data: { id: "edge107", source: "eqtype", target: "ssrfun" } },
-{ data: { id: "edge108", source: "countalg", target: "polyXY" } },
-{ data: { id: "edge109", source: "all_algebra", target: "polyXY" } },
-{ data: { id: "edge110", source: "separable", target: "polyXY" } },
-{ data: { id: "edge111", source: "presentation", target: "morphism" } },
-{ data: { id: "edge112", source: "automorphism", target: "morphism" } },
-{ data: { id: "edge113", source: "algC", target: "algebraics_fundamentals" } },
-{ data: { id: "edge114", source: "ssrnat", target: "eqtype" } },
-{ data: { id: "edge115", source: "fieldext", target: "falgebra" } },
-{ data: { id: "edge116", source: "all_character", target: "vcharacter" } },
-{ data: { id: "edge117", source: "mxabelem", target: "mxrepresentation" } },
-{ data: { id: "edge118", source: "character", target: "mxrepresentation" } },
-{ data: { id: "edge119", source: "zmodp", target: "finalg" } },
-{ data: { id: "edge120", source: "all_ssreflect", target: "binomial" } },
-{ data: { id: "edge121", source: "ssralg", target: "binomial" } },
-{ data: { id: "edge122", source: "perm", target: "binomial" } },
-{ data: { id: "edge123", source: "abelian", target: "sylow" } },
-{ data: { id: "edge124", source: "alt", target: "sylow" } },
-{ data: { id: "edge125", source: "algebraics_fundamentals", target: "sylow" } },
-{ data: { id: "edge126", source: "quotient", target: "automorphism" } },
-{ data: { id: "edge127", source: "mxrepresentation", target: "pgroup" } },
-{ data: { id: "edge128", source: "sylow", target: "pgroup" } },
-{ data: { id: "edge129", source: "finmodule", target: "cyclic" } },
-{ data: { id: "edge130", source: "center", target: "cyclic" } },
-{ data: { id: "edge131", source: "separable", target: "cyclic" } },
-{ data: { id: "edge132", source: "pgroup", target: "cyclic" } },
-{ data: { id: "edge133", source: "ssrnum", target: "zmodp" } },
+{ data: { id: "edge104", source: "galois", target: "separable" } },
+{ data: { id: "edge105", source: "all_character", target: "inertia" } },
+{ data: { id: "edge106", source: "ssrbool", target: "ssrfun" } },
+{ data: { id: "edge107", source: "all_algebra", target: "polyXY" } },
+{ data: { id: "edge108", source: "separable", target: "polyXY" } },
+{ data: { id: "edge109", source: "all_algebra", target: "fraction" } },
+{ data: { id: "edge110", source: "algC", target: "algebraics_fundamentals" } },
+{ data: { id: "edge111", source: "ssrnat", target: "eqtype" } },
+{ data: { id: "edge112", source: "abelian", target: "sylow" } },
+{ data: { id: "edge113", source: "alt", target: "sylow" } },
+{ data: { id: "edge114", source: "algebraics_fundamentals", target: "sylow" } },
+{ data: { id: "edge115", source: "all_character", target: "vcharacter" } },
+{ data: { id: "edge116", source: "vcharacter", target: "integral_char" } },
+{ data: { id: "edge117", source: "zmodp", target: "finalg" } },
+{ data: { id: "edge118", source: "all_ssreflect", target: "binomial" } },
+{ data: { id: "edge119", source: "perm", target: "binomial" } },
+{ data: { id: "edge120", source: "ssralg", target: "binomial" } },
+{ data: { id: "edge121", source: "quotient", target: "automorphism" } },
+{ data: { id: "edge122", source: "sylow", target: "pgroup" } },
+{ data: { id: "edge123", source: "mxrepresentation", target: "pgroup" } },
+{ data: { id: "edge124", source: "presentation", target: "morphism" } },
+{ data: { id: "edge125", source: "automorphism", target: "morphism" } },
+{ data: { id: "edge126", source: "finmodule", target: "cyclic" } },
+{ data: { id: "edge127", source: "center", target: "cyclic" } },
+{ data: { id: "edge128", source: "separable", target: "cyclic" } },
+{ data: { id: "edge129", source: "pgroup", target: "cyclic" } },
+{ data: { id: "edge130", source: "action", target: "quotient" } },
+{ data: { id: "edge131", source: "mxabelem", target: "mxrepresentation" } },
+{ data: { id: "edge132", source: "character", target: "mxrepresentation" } },
+{ data: { id: "edge133", source: "finfun", target: "tuple" } },
 { data: { id: "edge134", source: "matrix", target: "zmodp" } },
 { data: { id: "edge135", source: "cyclic", target: "zmodp" } },
-{ data: { id: "edge136", source: "action", target: "quotient" } },
-{ data: { id: "edge137", source: "finfun", target: "tuple" } },
-{ data: { id: "edge138", source: "eqtype", target: "ssrbool" } },
-{ data: { id: "edge139", source: "interval", target: "ssrint" } },
-{ data: { id: "edge140", source: "rat", target: "ssrint" } },
-{ data: { id: "edge141", source: "mxpoly", target: "polydiv" } },
-{ data: { id: "edge142", source: "fraction", target: "polydiv" } },
-{ data: { id: "edge143", source: "closed_field", target: "polydiv" } },
-{ data: { id: "edge144", source: "intdiv", target: "polydiv" } },
-{ data: { id: "edge145", source: "mxabelem", target: "maximal" } },
-{ data: { id: "edge146", source: "extremal", target: "maximal" } },
-{ data: { id: "edge147", source: "hall", target: "maximal" } },
-{ data: { id: "edge148", source: "all_field", target: "finfield" } },
-{ data: { id: "edge149", source: "all_algebra", target: "intdiv" } },
-{ data: { id: "edge150", source: "algebraics_fundamentals", target: "intdiv" } },
-{ data: { id: "edge151", source: "cluster_algebra", target: "cluster_fingroup" } },
-{ data: { id: "edge152", source: "cluster_fingroup", target: "cluster_ssreflect" } },
-{ data: { id: "edge153", source: "cluster_solvable", target: "cluster_algebra" } },
-{ data: { id: "edge154", source: "cluster_all", target: "cluster_character" } },
-{ data: { id: "edge155", source: "cluster_field", target: "cluster_solvable" } },
-{ data: { id: "edge156", source: "cluster_character", target: "cluster_field" } },
+{ data: { id: "edge136", source: "rat", target: "ssrint" } },
+{ data: { id: "edge137", source: "ring_quotient", target: "ssralg" } },
+{ data: { id: "edge138", source: "mxabelem", target: "maximal" } },
+{ data: { id: "edge139", source: "extremal", target: "maximal" } },
+{ data: { id: "edge140", source: "hall", target: "maximal" } },
+{ data: { id: "edge141", source: "all_field", target: "finfield" } },
+{ data: { id: "edge142", source: "eqtype", target: "ssrbool" } },
+{ data: { id: "edge143", source: "all_algebra", target: "intdiv" } },
+{ data: { id: "edge144", source: "algebraics_fundamentals", target: "intdiv" } },
+{ data: { id: "edge145", source: "cluster_algebra", target: "cluster_fingroup" } },
+{ data: { id: "edge146", source: "cluster_fingroup", target: "cluster_ssreflect" } },
+{ data: { id: "edge147", source: "cluster_solvable", target: "cluster_algebra" } },
+{ data: { id: "edge148", source: "cluster_all", target: "cluster_character" } },
+{ data: { id: "edge149", source: "cluster_test_suite", target: "cluster_all" } },
+{ data: { id: "edge150", source: "cluster_field", target: "cluster_solvable" } },
+{ data: { id: "edge151", source: "cluster_character", target: "cluster_field" } },
  ]; 
